-- 道具获取途径
Lua_ObtainPathWindow = class("Lua_ObtainPathWindow", Lua_Window)
function Lua_ObtainPathWindow:ctor()
    self:superCall("ctor");

    self.layer = Lua_MainWinDefine.TIPS_WINDOW_LAYER;
    self.windowName = "Lua_ObtainPathWindow";
    self.skinName = "ObtainPathWindow_skin";
    self.showBlackMask = true;
    self.isClickClose = true;
end

function Lua_ObtainPathWindow:buildShowItem()
    self:superCall("buildShowItem");
    self:addLuaEvent("PACK_ITEMS_UPDATE", self, self.updatePathList); -- 背包更新
    self:addLuaEvent("UPDATE_DAILYGIFT_INFO", self, self.updatePathList); -- 每日礼包
    self:addLuaEvent("UPDATE_MONTHLYGIFT_INFO", self, self.updatePathList); -- 每周礼包
    self:addLuaEvent("UPDATE_WEEKLYGIFT_INFO", self, self.updatePathList); -- 每月礼包

    self.itemIcon = Lua_ItemIcon.new(self.content);
    self.itemIcon:setLocation(-217, 236.5, 0);
    self.itemIcon:setCanClick(false);

    self.textArea = Lua_TextArea.new(self.content, 435, 80);
    self.textArea:setLocation(103, 185, 0);

    self.itemList = Lua_DragContainer.new(self.content, 638, 570, Lua_AxisDefine.Vertical);
    self.itemList:setLocation(1, -173.5, 0);
    self.itemList.tweenId = 2002;
    self.itemList:setCellSpacing(0, 5);
end

function Lua_ObtainPathWindow:dispose()
    if self.itemIcon ~= nil then
        self.itemIcon:dispose();
        self.itemIcon = nil;
    end
    if self.textArea ~= nil then
        self.textArea:dispose();
        self.textArea = nil;
    end
    if self.itemList ~= nil then
        self.itemList:dispose();
        self.itemList = nil;
    end
    self:superCall("dispose");
end

function Lua_ObtainPathWindow:showWin(param)
    self:superCall("showWin", param);
    
    self.itemIcon:setData(param);
    self.itemIcon:showNum(0);
    self.nameText.text = param.name;
    
    local count = DataCenter.packData:getItemCountById(param.id);
    self.haveCount.text = LanUtil.formateStr(309009, numberTrans(count));
    self.textArea:setText(param.des, 25, 1, 0, "726763");

    self:updatePathList();
end

function Lua_ObtainPathWindow:updatePathList()
    self.itemList:clearList();

    local bValue = true;
    local arr = self.showData.obtainPath;
    if arr ~= nil then
        local config;
        for i = 1, arr:getSize() do
            bValue = false;
            config = getConfig("obtain_path", arr[i][1]);
            if config.type == 1 then
                self.itemList:addSubContainer(Lua_ObtainPathItemCell, arr[i], false);
            elseif config.type == 2 then
                self.itemList:addSubContainer(Lua_ObtainPathGiftCell, arr[i], false);
            end
        end
    end

    arr = self.showData.funcPath;
    if arr ~= nil then
        for i = 1, arr:getSize() do
            bValue = false;
            self.itemList:addSubContainer(Lua_ObtainPathCell, arr[i], false);
        end
    end
    self.itemList:updateChildPos();

    self:showNone(bValue);
end

function Lua_ObtainPathWindow:showNone(bValue)
    if bValue then
        if self.noneIcon == nil then
            self.noneIcon = UICreate.createUIAtlasImage(self.content, "common_altas_3", "xui_common_widget_012", 0, -173.5, 0, 0);
            
            self.noneText = UICreate.createLabel(self.content, nil, 0, -205, 100, 40, 40);
            self.noneText.pivotValue = 4;
            self.noneText.fontName = Lua_MyUISettings.huakangFontName;
            self.noneText.alignmentValue = 4;
            self.noneText.horizontalOverflowValue = 1;
            self.noneText.colorStr = Lua_ColorDefine.transColorStr("938680");
            self.noneText:setLangValue(309086);
        end
        self.noneIcon:setEnable(true);
        self.noneText:setEnable(true);
    else
        if self.noneIcon then
            self.noneIcon:setEnable(false);
            self.noneText:setEnable(false);
        end
    end
end










Lua_ObtainPathItemCell = class("Lua_ObtainPathItemCell", Lua_DragContainerItem)
function Lua_ObtainPathItemCell:ctor(p)
    self:superCall("ctor", p, "ObtainPathItemCell_skin");
end

function Lua_ObtainPathItemCell:buildShowItem()
    self:superCall("buildShowItem");
    self.btnUse:addClickFuntion(self, self.onBtnUseClick);
end

function Lua_ObtainPathItemCell:dispose(go)
    self.data = nil;
    self:superCall("dispose");
end

function Lua_ObtainPathItemCell:setData(data)
    self.recoIcon:setEnable(data[2] ~= nil and data[2] > 0);

    self.data = getConfig("obtain_path", data[1]);
    self.nameText.text = self.data.name;

    local itemId;
    for _, v in ipairs(self.data.use_item) do
        local list = DataCenter.packData:getItemListById(v);
        if list and list:getSize() > 0 then
            itemId = v;
            break;
        end
    end
    local config = getConfig("item", itemId);
    self.itemIcon:setAltas(config.atlas, config.sprite);
    self.itemText.text = config.name;
end

function Lua_ObtainPathItemCell:getWidth()
    return 638;
end

function Lua_ObtainPathItemCell:getHeight()
    return 132;
end

function Lua_ObtainPathItemCell:onBtnUseClick(go)
    Lua_WindowUtil.openWin("Lua_SelectItemsWindow", Lua_WinParam.ACTION_OPEN, self.data.use_item);
end










Lua_ObtainPathGiftCell = class("Lua_ObtainPathGiftCell", Lua_DragContainerItem)
function Lua_ObtainPathGiftCell:ctor(p)
    self:superCall("ctor", p, "ObtainPathGiftCell_skin");
end

function Lua_ObtainPathGiftCell:buildShowItem()
    self:superCall("buildShowItem");

    self.rewardList = Lua_ItemIconList.new(self.content);
    self.rewardList:setLocation(-265, -18, 0);
    self.rewardList.pivot = 1;
    self.rewardList.scaleVal = 0.52;

    self.btnBuy:addClickFuntion(self, self.onBtnBuyClick);
end

function Lua_ObtainPathGiftCell:dispose(go)
    if self.rewardList then
        self.rewardList:dispose();
        self.rewardList = nil;
    end
    self.data = nil;
    self:superCall("dispose");
end

function Lua_ObtainPathGiftCell:setData(data)
    local config = getConfig("obtain_path", data[1]);
    self.nameText.text = config.name;

    if config.gift_type == 1 then
        self.data = DataCenter.dailyGiftData:getDailyGiftVo(config.gift_id);
    elseif config.gift_type == 2 then
        self.data = DataCenter.weeklyGiftData:getWeeklyGiftVo(config.gift_id);
    elseif config.gift_type == 3 then
        self.data = DataCenter.monthlyGiftData:getMonthlyGiftVo(config.gift_id);
    end
    self.rewardList:setArrayData(self.data.reward);
    self.quotaText.text = LanUtil.formateStr(config.show_label, self.data.curLimitTimes, self.data.limit_times);

    config = Lua_RechargeConfigData.getRechargeConfig(config.gift_id);
    -- self.originalText.text = LanUtil.formateStr(309084, tostring(config.originalPrice));
    self.btnBuy.label = LanUtil.formateStr(309083, tostring(config.money));
end

function Lua_ObtainPathGiftCell:getWidth()
    return 638;
end

function Lua_ObtainPathGiftCell:getHeight()
    return 132;
end

function Lua_ObtainPathGiftCell:onPressClick()
    self.rewardList:onBoundClick();
end

function Lua_ObtainPathGiftCell:onBtnBuyClick(go)
    if self.data.recharge == 0 then
        Lua_ProxyManager.getProxy("Lua_RaccoonMartProxy"):sGetDailyGiftReward(self.data.id);
    else
        DataCenter.sdkInterface:PointOutById(1, self.data.id);
    end
end












Lua_ObtainPathCell = class("Lua_ObtainPathCell", Lua_DragContainerItem)
function Lua_ObtainPathCell:ctor(p)
    self:superCall("ctor", p, "ObtainPathCell_skin");
end

function Lua_ObtainPathCell:buildShowItem()
    self:superCall("buildShowItem");
    self.btnGoto:addClickFuntion(self, self.onBtnGotoClick);
end

function Lua_ObtainPathCell:dispose(go)
    self.data = nil;
    self:superCall("dispose");
end

function Lua_ObtainPathCell:setData(data)
    self.recoIcon:setEnable(data[2] ~= nil and data[2] > 0);

    self.data = DataCenter.funcPathUtil:getFuncPathVo(data[1]);
    if self.data == nil then
        self.nameText:setEnable(false);
        self.btnGoto:setEnable(false);
        self.promptText:setEnable(false);
    else
        self.nameText:setEnable(true);
        self.nameText.text = self.data.name;
        if strIsNullOrEmpty(self.data.btn_name) then
            self.btnGoto:setEnable(false);
        else
            if self.data.openState then
                self.btnGoto:setEnable(not self.data.isShowing);
                self.promptText:setEnable(false);
            else
                self.btnGoto:setEnable(false);
                self.promptText:setEnable(true);
                self.promptText.text = self.data.promptStr;
            end
        end
    end
end

function Lua_ObtainPathCell:getWidth()
    return 638;
end

function Lua_ObtainPathCell:getHeight()
    return 132;
end

function Lua_ObtainPathCell:onBtnGotoClick(go)
    if self.data == nil then
        return;
    end
    if DataCenter.funcPathUtil:gotoFunction(self.data.id, true) then
        Lua_WindowUtil.openWin("Lua_ObtainPathWindow", Lua_WinParam.ACTION_CLOSE);
    end
end