Lua_PackWindow = class("Lua_PackWindow", Lua_Window);
function Lua_PackWindow:ctor()
    self:superCall("ctor");

    self.windowName = "Lua_PackWindow";
    self.showBlackMask = true;
    self.showWinBg = true;
    self.winBgPath = "/images/common/xui_common_window_001.png";
    self.winBgPosY = 22.5;
    self.showTitle = true;
    self.titleText = LanUtil.getValue(309068);
    self.titleNamePosY = 485;
    self.showClose = true;
    self.btnCloseAtlas = "common_altas_1";
    self.btnCloseSprite = "xui_common_button_001_n";
    self.btnClosePosX = 306;
    self.btnClosePosY = 496;
    self.isClickClose = true;
    self:addPreLoadRes(self.winBgPath, Lua_LoadFileType.IMG);
end

function Lua_PackWindow:buildShowItem()
    self:superCall("buildShowItem");
    self:addLuaEvent("PACK_TYPE_SELECT", self, self.onPackTypeSelect);

    self.titleName.effectStyle = 2;
    self.titleName.effectColorStr = Lua_ColorDefine.transColor("F3E7D5");
    self.titleName:setEffectDistance(2, 2);

    self.panelDic = {};
    self.packArr = DataCenter.packData:getPackTagList();

    self.buttonList = Lua_DragList.new(self.content, 650, 77, Lua_AxisDefine.Horizontal);
    self.buttonList:setSiblingIndex(0);
    self.buttonList:setLocation(0, -570, 0);
    self.buttonList:setListCell(Lua_PackTypeItem, 133, 77, 1);
    self.buttonList:setCellSpacing(5, 0);
    self.buttonList.clickMoveOffset = 1;
    self.buttonList.callBackOwner = self;
    self.buttonList.dragCallBack = self.updateArrow;
    self.buttonList:setArrayData(self.packArr);

    self.leftArrow = UICreate.createUIAtlasImage(self.content, "vip_atlas", "xui_vip_widget_10", -335, -560, 0, 0);
    self.leftArrow:setScale(-1, 1, 1);
    self.rightArrow = UICreate.createUIAtlasImage(self.content, "vip_atlas", "xui_vip_widget_10", 335, -560, 0, 0);
end

function Lua_PackWindow:dispose()
    if self.panelDic ~= nil then
        for k,v in pairs(self.panelDic) do
            v:dispose();
        end
        self.panelDic = nil;
    end
    self.showPanel = nil;
    if self.buttonList ~= nil then
        self.buttonList:dispose();
        self.buttonList = nil;
    end
    self.packArr = nil;
    self:superCall("dispose");
end

function Lua_PackWindow:showWin(param)
    local packType;
    if type(param) == "table" then
        packType = param.main_id;
    elseif type(param) == "number" then
        packType = param;
    end

    local index;
    for i = 1, self.packArr:getSize() do
        if self.packArr[i].package == packType then
            index = i;
            break;
        end
    end
    index = index == nil and 1 or index;
    self.buttonList:moveToIndex(index, true);
    self.buttonList:setSelectClick(index);
    self.buttonList:setSelected(index);
end

function Lua_PackWindow:updateArrow(curSubPos)
    self.leftArrow:setEnable(curSubPos <= 86);
    self.rightArrow:setEnable(curSubPos >= -86);
end

function Lua_PackWindow:onPackTypeSelect(data)
    if self.selectedType == data.package or strIsNullOrEmpty(data.panel_name) then
        return;
    end
    self.selectedType = data.package;

    for k,v in pairs(self.panelDic) do
        v:setEnable(false)
    end
    if self.panelDic[data.panel_name] == nil then
        local showPanel = checkRequire(data.panel_name);
        self.panelDic[data.panel_name] = showPanel.new(self.content)
    end
    self.showPanel = self.panelDic[data.panel_name]
    self.showPanel:setEnable(true)
    self.showPanel:setData(data)
end











Lua_PackTypeItem = class("Lua_PackTypeItem", Lua_ListCell)
function Lua_PackTypeItem:ctor(p)
    self:superCall("ctor", p);
end

function Lua_PackTypeItem:buildShowItem()
    self:superCall("buildShowItem");

    self.btnBg = UICreate.createUIAtlasImage(self.content, "common_altas_1", "xui_common_tab_002", 0, 0, 0, 0);

    self.btnText = UICreate.createLabel(self.content, nil, 0, 10, 100, 31, 30);
    self.btnText.pivotValue = 4;
    self.btnText.alignmentValue = 4;
    self.btnText.fontName = Lua_MyUISettings.huakangFontName;
    self.btnText.colorStr = Lua_ColorDefine.transColor("7A6A5F");
    self.btnText.horizontalOverflowValue = 1;
end

function Lua_PackTypeItem:dispose()
    if self.redPointIcon then
        self.redPointIcon:dispose();
        self.redPointIcon = nil;
    end
    self.data = nil;
    self:superCall("dispose");
end

function Lua_PackTypeItem:setData(data)
    self.data = data;
    self.btnText.text = data.textStr;
    self:showRedPoint(data.redPointId);
end

function Lua_PackTypeItem:onSelectionChange(bSelected)
    self:superCall("onSelectionChange", bSelected);
    if bSelected then
        self.btnBg:setAltas("common_altas_1", "xui_common_tab_001");
        self.btnText.colorStr = Lua_ColorDefine.transColor("8F5123");
    else
        self.btnBg:setAltas("common_altas_1", "xui_common_tab_002");
        self.btnText.colorStr = Lua_ColorDefine.transColor("7A6A5F");
    end
end

function Lua_PackTypeItem:onPressClick()
    Lua_MsgUtil.callFunc("PACK_TYPE_SELECT", self.data);
    if self.redPointIcon then
        self.redPointIcon:clickHandler();
    end
    return true;
end

function Lua_PackTypeItem:showRedPoint(redPointId)
    if DataCenter.redPointData:hasRedPointVoById(redPointId) then
        if self.redPointIcon == nil then
            self.redPointIcon = Lua_RedPointIcon.new(self.content, redPointId);
            self.redPointIcon:setLocation(45, 15);
        else
            self.redPointIcon:setEnable(true);
            self.redPointIcon:changeRedPoint(redPointId);
        end
    else
        if self.redPointIcon then
            self.redPointIcon:setEnable(false);
        end
    end
end