Lua_SelectItemsWindow = class("Lua_SelectItemsWindow", Lua_Window)
function Lua_SelectItemsWindow:ctor()
	self:superCall("ctor");

	self.layer = Lua_MainWinDefine.TIPS_WINDOW_LAYER;
	self.windowName = "Lua_SelectItemsWindow";
	self.skinName = "SelectItemsWindow_skin";
	self.showBlackMask = true;
	self.isClickClose = true;
end

function Lua_SelectItemsWindow:buildShowItem()
	self:superCall("buildShowItem");
	self:addLuaEvent("PACK_ITEMS_UPDATE", self, self.updateShowInfo);
	self:addLuaEvent("SELECT_ITEM_UPDATE", self, self.onItemSelected);
	
	self.itemList = Lua_DragList.new(self.content, 580, 322, Lua_AxisDefine.Vertical);
	self.itemList:setLocation(0, 52);
	self.itemList:setListCell(Lua_SelectItemsCell, 100, 139, 5);
	self.itemList:setCellSpacing(20, 5);

	self.desText:setLangValue(309085);
	self.btnSubmit:addClickFuntion(self, self.onBtnSubmitClick);
end

function Lua_SelectItemsWindow:dispose()
	if self.itemList then
		self.itemList:dispose();
		self.itemList = nil;
	end
	self:superCall("dispose");
end

function Lua_SelectItemsWindow:showWin(param)
	self:superCall("showWin", param);
	self:updateShowInfo();
end

function Lua_SelectItemsWindow:updateShowInfo()
	self.itemUnId = nil;
	self.itemList.curSelectedIdx = nil;

	local arr = Array();
	local data;
	for _, y in ipairs(self.showData) do
		data = DataCenter.packData:getItemListById(y);
		if data then
			for i = 1, data:getSize() do
				arr:add(data[i]);
			end
		end
	end
	if arr:getSize() <= 0 then
		self:hide();
		return;
	end
	self.itemList:setArrayData(arr);
end

function Lua_SelectItemsWindow:onItemSelected(itemUnId)
	self.itemUnId = itemUnId;
end

function Lua_SelectItemsWindow:onBtnSubmitClick(go)
	if self.itemUnId == nil then
		OperateAlert.showLangValue(309085);
		return;
	end
	
	local vo = DataCenter.packData:getItemVoByUnId(self.itemUnId);
	DataCenter.packUtil:showItemInfo(vo, true);
end










Lua_SelectItemsCell = class("Lua_SelectItemsCell", Lua_ListCell)
function Lua_SelectItemsCell:buildShowItem()
	self:superCall("buildShowItem");

	self.itemIcon = Lua_ItemIcon.new(self.content);
	self.itemIcon:setScale(0.8, 0.8, 1);
	self.itemIcon:setLocation(0, 15, 0);

	self.nameText = UICreate.createLabel(self.content, nil, 0, -53, 100, 31, 24);
	self.nameText.pivotValue = 4;
	self.nameText.alignmentValue = 4;
	self.nameText.horizontalOverflowValue = 1;
	self.nameText.verticalOverflowValue = 0;
	self.nameText.colorStr = Lua_ColorDefine.transColor("856545");
end

function Lua_SelectItemsCell:dispose()
	if self.itemIcon then
		self.itemIcon:dispose();
		self.itemIcon = nil;
	end
	if self.scrollText then
		self.scrollText:dispose();
		self.scrollText = nil;
	end
	self.nameText = nil;
	self.data = nil;
	self:superCall("dispose");
end

function Lua_SelectItemsCell:setData(data)
	self.data = data;

	local vo = DataCenter.packData:getItemVoByUnId(data);
	self.itemIcon:setData(vo);
	self.nameText.text = vo.name;
	self.nameText:resetSize();
	if self.nameText.width > 100 then
		self.nameText:setEnable(false);
		if self.scrollText == nil then
			self.scrollText = Lua_ScrollText.new(self.content, Lua_AxisDefine.Horizontal, 100, 24);
			self.scrollText:setLocation(0, -53, 0);
			self.scrollText:setTextStyle(100, 24, Lua_MyUISettings.defaultFontName, 24, "856545", 0);
	    end
		self.scrollText:setEnable(true);
		self.scrollText:setShowTxt(vo.name);
	else
		self.nameText:setEnable(true);
		if self.scrollText then
			self.scrollText:setEnable(false);
		end
	end
end

function Lua_SelectItemsCell:onSelectionChange(bSelected)
	self:superCall("onSelectionChange", bSelected);
	self.itemIcon:setDrawMask(bSelected);
end

function Lua_SelectItemsCell:onPressClick()
	if self.data == nil then
		return;
	end
	Lua_MsgUtil.callFunc("SELECT_ITEM_UPDATE", self.data);
	return true;
end